@@ -40,7 +40,11 @@ logd_prior <- function(x, pdf, hypers){
   if (pdf == 'mvnorm'){
     stop('multivariate priors not implemented')
     } else {
-    lp <- do.call(paste("d",pdf, sep=''), args=append(list(x, log=TRUE), hypers))
+      if (pdf == 'trunc'){#handle inconsistent behaviour of truncdist, which silently fails (i.e. produces incorrect output) with log = TRUE
+        lp <- log(do.call(paste("d",pdf, sep=''), args=append(list(x, log = FALSE), hypers)))
+      } else {
+        lp <- do.call(paste("d",pdf, sep=''), args=append(list(x, log=TRUE), hypers))
+      }
     return(lp)
     }
 }
@@ -58,12 +62,15 @@ logd_prior <- function(x, pdf, hypers){
 #' @param joint integer; number of block for joint proposal; NULL means the parameter is not to be jointly proposed
 #' @param prior character; name of the probability distribution for the prior on the parameter. Must conform to standard R naming of d/r function pairs, e.g. beta ( foo = beta), binomial binom, Cauchy cauchy, chi-squared chisq, exponential exp, Fisher F f, gamma gamma, geometric geom, hypergeometric hyper, logistic logis, lognormal lnorm, negative binomial nbinom, normal norm, Poisson pois, Student t t, uniform unif, Weibull weibull. Priors from the truncdist package are available by default. User priors can be provided but must be available in the environment from which de_mcmc is called.
 #' @param hypers list of numeric vectors, hyperparameters for the prior; mean only for mvnorm. Can include trunc for truncated pdfs from package truncdist.
-#' @param prop.var numeric; tuning parameters, that is the standard deviation of the proposal distribution for each parameter
+#' @param prop.var numeric; tuning parameters. For Normal proposals (`samp.type="rw"` or `samp.type="rw-ref"`), this must be a positive number representing the standard deviation of the proposal distribution for each parameter. For the asymmetric uniform proposal distribution (`samp.type="rw-unif"`) two positive numeric values are required and the proposal will then have the bounds `prop.var[1]/prop.var[2]*current_proposal` and `prop.var[2]/prop.var[1]*current_proposal`. See Boersch-Supan et al. (2016).
 #' @param samp.type character; type of sampler: "rw" = Normal random walk, "ind" = independence, "rw-unif" = asymmetric uniform distribution, "rw-ref" = reflecting random walk sampler on the bounds of the prior support (cf. Hoff 2009, Chapter 10.5.1; Yang and Rodriguez 2013)
 #'
 #' @return returns an object of class debinfer_par to be fed to the mcmc setup function
-#' @references Hoff 2009, A First Course in Bayesian Statistical Methods, Springer
-#'             Yang and Rodriguez 2013, PNAS 110:19307-19312 \url{http://doi.org/10.1073/pnas.1311790110}
+#' @references Boersch-Supan et al. 2016, MEE 8:511-518 \doi{10.1111/2041-210X.12679}
+#'
+#'             Hoff 2009, A First Course in Bayesian Statistical Methods, Springer
+#'
+#'             Yang and Rodriguez 2013, PNAS 110:19307-19312 \doi{10.1073/pnas.1311790110}
 #' @export
 debinfer_par <- function(name, var.type, fixed, value, joint=NULL, prior=NULL, hypers=NULL, prop.var=NULL, samp.type=NULL){
   #check inputs
@@ -117,7 +124,7 @@ debinfer_par <- function(name, var.type, fixed, value, joint=NULL, prior=NULL, h
 #'
 debinfer_cov <- function(var.names, sigma=diag(length(names)), name , samp.type = "rw"){
   if(!is.character(var.names)) stop("var.names must be a character vector")
-  if(class(sigma)!= "matrix" || !is.numeric(sigma)) stop("sigma must be a numeric matrix")
+  if(!is.matrix(sigma) | !is.numeric(sigma)) stop("sigma must be a numeric matrix")
   if (!isSymmetric(sigma)) stop("sigma must be symmetric")
   if (!all(eigen(sigma, only.values = TRUE)$values>0)) warning("sigma does not appear to be positive semi-definite")
   if(any(dim(sigma)!=length(var.names))) stop("length(var.names) does not match dimensions of sigma")
